@@ -1,6 +1,6 @@
 from django.contrib.auth import SESSION_KEY
 from django.conf import settings
-from django.http import HttpResponse
+from rest_framework.response import Response
 from errors import WsResponseError, WsInvocationError
 import httplib, json, proxy_server
 
