@@ -7,9 +7,7 @@ import json
 @expose_service(['POST'], public=True)
 def test(request):
     service_url = generate_service_url('/login')
-    response = invoke_backend_service_as_proxy('POST', service_url, json_data={ 'email':'admin@test.com', 'password':'password' }, request=request)
-    print type(response)
-    return response
+    return invoke_backend_service_as_proxy('POST', service_url, json_data={ 'email':'admin@test.com', 'password':'password' }, request=request)
 
 
 @expose_service(['GET'], public=True)
